OUTPUT_DIR_STR = 'output_dir'
SLICE_STR = 'slice'
NAME_STR = 'name'
FILE_STR = 'file'
JSON_STR = 'json'
RATE_STR = 'rate'
MESSAGES_STR = 'messages'